pub struct DocumentId(/* private fields */);Expand description
A unique document identifier per sender and document type (max 35 chars,
case-sensitive). Used as DocumentIdentification, OrderIdentification,
AllocationIdentification, mRID, etc.
Implementations
Sourceimpl DocumentId
impl DocumentId
Sourcepub fn new(s: impl Into<String>) -> Result<Self, RedispatchXmlError>
pub fn new(s: impl Into<String>) -> Result<Self, RedispatchXmlError>
Create a new DocumentId, returning an error if the value is empty or
longer than 35 characters.