SrObjekt

Struct SrObjekt 

pub struct SrObjekt {
Show 15 fields pub klarname: Option<String>, pub anschluss_netzbetreiber: NbRef, pub anweisender_netzbetreiber: Option<NbRef>, pub betroffene_netzbetreiber: Vec<BetroffenerNb>, pub weitere_betroffene_netzbetreiber: Vec<NbRef>, pub energietraeger: Option<Energietraeger>, pub verguetungsart: Option<Verguetungsart>, pub status_duldungsfall: Option<StatusDuldungsfall>, pub steuerbarkeit: Option<Steuerbarkeit>, pub abrufart_aufforderungsfall: Option<AbrufartAufforderungsfall>, pub bilanzierungsmodell: Bilanzierungsmodell, pub individuelle_quote: Option<IndividuelleQuote>, pub regelzone: Regelzone, pub technische_parameter: Option<TechnischeParameter>, pub enthaltene_tr: Vec<EnthaltenesTr>,
}
A steuerbare Ressource (controllable resource) object.

Each SR_Objekt describes one resource or cluster that participates in the Redispatch 2.0 process.

Fields

klarname: Option<String>

Human-readable name (optional, max 35 chars, [A-Z0-9\-+_]*).

anschluss_netzbetreiber: NbRef

Network connection point operator.

anweisender_netzbetreiber: Option<NbRef>

Ordering grid operator (optional — absent when same as connection NB).

betroffene_netzbetreiber: Vec<BetroffenerNb>

Affected grid operators in cascade order (up to 6).

weitere_betroffene_netzbetreiber: Vec<NbRef>

Additional affected grid operators beyond the cascade of 6.

energietraeger: Option<Energietraeger>

Energy carrier.

verguetungsart: Option<Verguetungsart>

Compensation type.

status_duldungsfall: Option<StatusDuldungsfall>

Tolerance case status.

steuerbarkeit: Option<Steuerbarkeit>

Controllability definition.

abrufart_aufforderungsfall: Option<AbrufartAufforderungsfall>

Call type for demand requests.

bilanzierungsmodell: Bilanzierungsmodell

Billing model.

individuelle_quote: Option<IndividuelleQuote>

Individual allocation quota percentages.

regelzone: Regelzone

Control zone (Regelzone / TSO EIC code).

technische_parameter: Option<TechnischeParameter>

Technical parameters of the resource (optional).

enthaltene_tr: Vec<EnthaltenesTr>

Contained technical resources (for cluster / control group resources).